### CS&SS 569 - Visualizing Data and Models
##
## Introduction to Shiny, app 2 - interactive ggplot (button version)
##
## TA: Ramses Llobet


# load libraries

library(shiny)
library(tidyverse)
library(gapminder)


# user interface

ui <- fluidPage(
  
  titlePanel("Gapminder data"),
  
  sidebarLayout(
    
    sidebarPanel(
      checkboxGroupInput(
        inputId = "continent", 
        label = "Continent(s) to include",
        choices = unique(gapminder$continent),
        selected = "Asia"
      ),
      actionButton(inputId = "update", label = "Update"),
    ),
    mainPanel(
      plotOutput("GMplot")
    )
  )
)

# server function

server <- function(input, output) {
  
  update_data <- eventReactive(input$update, {
      gapminder %>% 
      filter(continent %in% input$continent)
  })
  
  output$GMplot <- renderPlot({
    ## Plot data according to input$yvar
    update_data() %>%
      ggplot(aes(x = year, y = gdpPercap, color = continent)) +
      geom_smooth() +
      geom_jitter(alpha = 0.2) +
      scale_y_log10() +
      theme_bw()
  })

}

# run shinyApp

shinyApp(ui = ui, server = server)


