### CS&SS 569 - Visualizing Data and Models
##
## Introduction to Shiny, based on Wickham 2021 - Chp 1
## Link: https://mastering-shiny.org/index.html
##
## TA: Ramses Llobet


# One thing, I recommend turning on 
# Global Options :: Code :: Display :: Show indent guides


## Make sure to install shiny

if (!requireNamespace("shiny", quietly = TRUE)) install.packages("shiny")

# load library

library(shiny)


#_________ 1. geeing started _______#


## Two essential pieces to build a Shiny app:

# 1. ui (user interface): defines how your app looks.
# 2. server (function): defines how your app works.


# 1.

ui <- fluidPage(
  "Hello, world!"
)


# 2.

server <- function(input, output) {
  
  # empty, the app doesn't do anything
  
}

# 3. run your shiny app

shinyApp(ui, server)


# Notice in the console an address like: 

# "Listening on http://127.0.0.1:5452"

# This tells you the URL where your app can be found: 127.0.0.1 
# is a standard address that means “this computer” and 5452 is 
# a randomly assigned port number.



#_________ 2. Adding UI controls _______#

# 1.

ui <- fluidPage(
  selectInput(inputId ="dataset", 
              label = "Dataset", 
              choices = ls("package:datasets")),
  verbatimTextOutput("summary"),
  tableOutput("table")
)


# - fluidPage() is a layout function that sets up the basic visual 
#   structure of the page


# - selectInput() is an input control that lets the user interact with 
#   the app by providing a value. In this case, it’s a select box with 
#   the label “Dataset” and lets you choose one of the built-in datasets 
#   that come with R.


#  - verbatimTextOutput() and tableOutput() are output controls that 
#    tell Shiny where to put rendered output



# 2. Same server function as before



# 3. run your shiny app

shinyApp(ui, server)




#_________ 3. Adding behavior _______#


# 1. Same ui object as before



# 2.

server <- function(input, output) {
  
  # renderPrint to print console text as ouput
  output$summary <- renderPrint({
    
    dataset <- get(input$dataset, "package:datasets")
    
    summary(dataset) # print summary output
  })
  
  # renderTable to display a table as ouput
  output$table <- renderTable({
    
    dataset <- get(input$dataset, "package:datasets")
    
    dataset # print table output
  })
}


# 3. run your shiny app

shinyApp(ui, server)


# Notice that the summary and table update whenever you change the 
# input dataset.

# This dependency is created implicitly because we’ve referred to 
# input$dataset within the output functions. input$dataset is 
# populated with the current value of the UI component with id 
# dataset, and will cause the outputs to automatically update 
# whenever that value changes. 

# This is the essence of reactivity: outputs automatically 
# react (recalculate) when their inputs change.





#_________ 4. reactive expressions _______#

# notice that we have duplicated code:

dataset <- get(input$dataset, "package:datasets") # duplicated

# you can avoid duplicates by creating - reactive expressions


# You create a reactive expression by wrapping a block of code in 
# reactive({...}) and assigning it to a variable, and you use a 
# reactive expression by calling it like a function.




# 1. Same ui object as before



# 2.

server <- function(input, output, session) {
  # Create a reactive expression
  dataset <- reactive({
    get(input$dataset, "package:datasets")
  })
  
  output$summary <- renderPrint({
    # Use a reactive expression by calling it like a function
    summary(dataset())
  })
  
  output$table <- renderTable({
    dataset()
  })
}


# 3. run your shiny app

shinyApp(ui, server)



















